@@ -109,6 +109,8 @@ class SerialConsoleOpsTestCase(test_base.HyperVBaseTestCase):
     @mock.patch.object(builtins, 'open')
     @mock.patch("os.path.exists")
     def test_get_console_output_exception(self, fake_path_exists, fake_open):
+        mock_handler = self._setup_console_handler_mock()
+
         self._serialops._vmutils.is_secure_vm.return_value = False
         self._serialops._pathutils.get_vm_console_log_paths.return_value = [
             mock.sentinel.log_path_1, mock.sentinel.log_path_2]
@@ -118,6 +120,7 @@ class SerialConsoleOpsTestCase(test_base.HyperVBaseTestCase):
         self.assertRaises(exception.ConsoleLogOutputException,
                           self._serialops.get_console_output,
                           mock.sentinel.instance_name)
+        mock_handler.flush_console_log.assert_called_once_with()
         fake_open.assert_called_once_with(mock.sentinel.log_path_2, 'rb')
 
     def test_get_console_output_secure_vm(self):
